@@ -9,12 +9,12 @@ repository operations for Vincent Driessen's branching model.
 # Distributed under a BSD-like license. For full terms see the file LICENSE.txt
 #
 
-VERSION = (0, 6, 17, 'dev')
+VERSION = (1, 0, 0)
 
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
-__author__ = "Tomas Brambora, Hartmut Goebelm, Vincent Driessen"
-__contact__ = "tomas@salsitasoft.com, h.goebel@crazy-compilers.com, vincent@datafox.nl"
+__author__ = "Ondrej Kupka, Tomas Brambora, Hartmut Goebelm, Vincent Driessen"
+__contact__ = "ondrejk@salsitasoft.com, tomas@salsitasoft.com, h.goebel@crazy-compilers.com, vincent@datafox.nl"
 __homepage__ = "http://github.com/salsita/gitflow/"
 __docformat__ = "restructuredtext"
-__copyright__ = "2010-2011 Vincent Driessen; 2012 Hartmut Goebel; 2013 Tomas Brambora"
+__copyright__ = "2010-2011 Vincent Driessen; 2012 Hartmut Goebel; 2013 Tomas Brambora, 2013 Ondrej Kupka"
 __license__ = "BSD"
